.. _v2_0:

Version 2.0
===========

Summary
-------

.. qrefflask:: flexmeasures.app:create(env="documentation")
    :blueprints: flexmeasures_api, flexmeasures_api_play, flexmeasures_api_v2_0
    :order: path
    :include-empty-docstring:

API Details
-----------

.. autoflask:: flexmeasures.app:create(env="documentation")
    :blueprints: flexmeasures_api, flexmeasures_api_play, flexmeasures_api_v2_0
    :order: path
    :include-empty-docstring:
